/*
Copyright (C) 2017 Belledonne Communications SARL

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef _LINPHONE_PARTICIPANT_DEVICE_LISTENER_HH
#define _LINPHONE_PARTICIPANT_DEVICE_LISTENER_HH

#include "enums.hh"
#include "object.hh"






namespace linphone {

	class ParticipantDevice;

	/**
	 *
	 */
	class ParticipantDeviceListener: public Listener {
	
		public:


	
		public:
			
		
			/**
			 * @brief Callback used to notify that is this participant device speaking has
			 * changed. 
			 *
			 * @param isSpeaking is this participant device speaking 
			 */
			LINPHONECXX_PUBLIC virtual void onIsSpeakingChanged(const std::shared_ptr<linphone::ParticipantDevice> & participantDevice, bool isSpeaking) {};
			
			/**
			 * @brief Callback used to notify that this participant device is muted or is no
			 * longer muted. 
			 *
			 * @param isMuted is this participant device muted 
			 */
			LINPHONECXX_PUBLIC virtual void onIsMuted(const std::shared_ptr<linphone::ParticipantDevice> & participantDevice, bool isMuted) {};
			
			/**
			 * @brief Callback used to notify that participant device changed state. 
			 *
			 * @param participantDevice LinphoneParticipantDevice object    
			 */
			LINPHONECXX_PUBLIC virtual void onStateChanged(const std::shared_ptr<linphone::ParticipantDevice> & participantDevice, linphone::ParticipantDeviceState state) {};
			
			/**
			 * @brief Callback used to notify that participant device stream capability has
			 * changed. 
			 *
			 * @param direction participant device's audio direction 
			 */
			LINPHONECXX_PUBLIC virtual void onStreamCapabilityChanged(const std::shared_ptr<linphone::ParticipantDevice> & participantDevice, linphone::MediaDirection direction, linphone::StreamType streamType) {};
			
			/**
			 * @brief Callback used to notify that participant device stream availability has
			 * changed. 
			 *
			 * @param participantDevice LinphoneParticipantDevice object    
			 */
			LINPHONECXX_PUBLIC virtual void onStreamAvailabilityChanged(const std::shared_ptr<linphone::ParticipantDevice> & participantDevice, bool available, linphone::StreamType streamType) {};
			
			
	};

};

#endif // _LINPHONE_PARTICIPANT_DEVICE_LISTENER_HH
